/*
	PrefArray.js
	Dashboard Widgetで配列を記憶するためのメソッド群。
	メソッドはWidgetオブジェクトに追加され、標準のメソッドと似た気分で使える。
	(widgetではなくWidgetという独自のオブジェクトである事に注意。)
	最初はwidget.prototypeに追加しようとしたんだけど、なんか出来なかった。
*/
/*  LICENSE = New BSD License (修正BSDライセンス)
Copyright (c) 2006, Yamanoue no Okela
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
    * Neither the name of the Okela nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


var Widget;
if(window.widget){
Widget = new Object();

function createKeyStringWithIndex(key, index){
	return "__Array_"+key+"_"+index;
}

/*
* widget.setPreferenceArrayForKey(array, key)
* 実際には、__Array_key_indexという形式のkeyのpreferenceが設定される。
* array : Arrayオブジェクト。中身は全てwidget.setPreferenceForKeyで設定可能な値(文字列等)でなければならない。
* また、arrayの要素にnullが含まれている場合は空の文字列("")に置き換えられる。従って、そのような場合はここで設定したarrayは後で取り出した物と完全に一致しない。
* これは、設定を取得するメソッドで数値の順に読み出し、設定の無いところにぶつかったら終了するという形式を取るためだ。
* arrayがundefilnedの場合は配列全体の設定がクリアされる。
* なお、連想配列には対応していない。読み出す手段が無いから。
*/
//widget.prototype.setPreferenceArrayForKey = function( array, key ){
Widget.setPreferenceArrayForKey = function( array, key ){
	if(array == undefined){ //全削除
		var i=0;
		while(true){
			var pref = widget.preferenceForKey(createKeyStringWithIndex(key,i));
			if(pref){
				//alert("DELETE"+pref);
				widget.setPreferenceForKey(null, createKeyStringWithIndex(key,i));
				i++;
			} else
				break;
		}
	}
	else if(array instanceof Array){
		for(var i=0; i<array.length; i++){ //設定する
			if(array[i] == null)
				array[i] = "";
			widget.setPreferenceForKey( array[i], createKeyStringWithIndex(key,i) );
		}
		var i=array.length; //配列の長さ以後の分はクリアする
		while(true){
			var pref = widget.preferenceForKey(createKeyStringWithIndex(key,i));
			if(pref){
				//alert("DELETE"+pref);
				widget.setPreferenceForKey(null, createKeyStringWithIndex(key,i));
				i++;
			} else
				break;
		}
		
	}else
		throw "Exception: Object Not Array.";
}


/*
* widget.preferenceArrayForKey(key)
* keyで保存された配列を返す。
*/
//widget.prototype.preferenceArrayForKey = function( key ){
Widget.preferenceArrayForKey = function( key ){
	var array = new Array();
	var i = 0;
	while(true){
		var pref = widget.preferenceForKey(createKeyStringWithIndex(key,i));
		if(pref){
			array.push(pref);
			i++;
		} else
			break;
	}
	return array;
}

}
